#
# spec file for package i3-gaps
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           i3-gaps
Version:        4.15.0.1
Release:        lp151.3.3
Summary:        Tiling window manager
License:        BSD-3-Clause
Group:          System/GUI/Other
Url:            https://github.com/Airblader/i3
Source0:        https://github.com/Airblader/i3/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         i3-asciidoc-fix.patch
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  libyajl-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(xkbcommon-x11)
# So that M-enter works in the default config. boo#985443
Recommends:     dmenu
Recommends:     i3lock
# introduced to fix bnc#971897 and boo#985443
Recommends:     i3status
Conflicts:      i3
# Needed to fix bnc#992972
Provides:       i3
Provides:       windowmanager
# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.

%description
i3-gaps is a fork of i3, which adds features such as gaps between tiles.

%package devel
Summary:        Development headers for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}
# i3 and i3-gaps both provide /usr/include/i3/ipc.h and the same docs
Conflicts:      i3-devel

%description devel
Development headers for the %{name} window manager

%prep
%setup -q -n i3-%{version}
%patch1 -p1

# fix rpmlint E: env-script-interpreter
sed -i 's,^#!/usr/bin/env ,#!/usr/bin/,' i3-dmenu-desktop i3-migrate-config-to-v4 i3-save-tree

%build
autoreconf -fi
# Fix Leap 42.x build
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse}
export YAJL_LIBS="-lyajl" YAJL_CFLAGS="-I/usr/include/yajl"
%endif
%configure
sed -i 's/(TEST_LOGS:/(TEST_LOGS):/' Makefile
make %{?_smp_mflags} V=1 -C *-suse-linux-gnu*

%install
%make_install
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/i3.desktop

%files
%license LICENSE
%doc RELEASE-NOTES-*
%{_mandir}/man1/i3*.1%{?ext_man}
%{_bindir}/i3
%{_bindir}/i3-dump-log
%{_bindir}/i3-with-shmlog
%{_bindir}/i3bar
%{_bindir}/i3-config-wizard
%{_bindir}/i3-dmenu-desktop
%{_bindir}/i3-input
%{_bindir}/i3-migrate-config-to-v4
%{_bindir}/i3-msg
%{_bindir}/i3-nagbar
%{_bindir}/i3-save-tree
%{_bindir}/i3-sensible-editor
%{_bindir}/i3-sensible-pager
%{_bindir}/i3-sensible-terminal
%dir %{_sysconfdir}/i3/
%config %{_sysconfdir}/i3/config
%config %{_sysconfdir}/i3/config.keycodes
%{_datadir}/xsessions/i3.desktop
%{_datadir}/xsessions/i3-with-shmlog.desktop
%{_datadir}/applications/i3.desktop

%files devel
%dir %{_includedir}/i3/
%dir %{_datadir}/doc/i3
%doc %{_datadir}/doc/i3/*.html
%{_includedir}/i3/ipc.h

%changelog
* Thu Apr 12 2018 tiwai@suse.de
- Fix build with asciidoctor (bsc#1075764):
  i3-asciidoc-fix.patch
* Thu Mar 15 2018 avindra@opensuse.org
- update to 4.15.0.1
  * minor: fix version so it's recognized as a release version.
* Sun Mar 11 2018 avindra@opensuse.org
- update to 4.15
  * i3-sensible-terminal: add “kitty”, “guake”, “tilda”
  * i3-sensible-editor: add “gvim”
  * dump-asy: add prerequisite checks
  * dump-asy: fix warnings about empty container names
  * i3-dump-log: enable shmlog on demand
  * i3bar: add --release flag for bindsym in bar blocks
  * i3bar: add relative coordinates in JSON for click events
  * ipc: rename COMMAND to RUN_COMMAND for consistency
  * ipc: implement tick event for less flaky tests
  * ipc: add error reply to “focus <window_mode>”
  * ipc: send success response for nop
  * introduce “assign <criteria> [→] [workspace] [number] <workspace>”
  * introduce “assign <criteria> [→] output left|right|up|down|primary|<output>”
  * introduce a “focus_wrapping” option (subsumes “force_focus_wrapping”)
  * introduce percentage point resizing for floating containers:
    “resize set <width> [px | ppt] <height> [px | ppt]”
  * introduce “resize set <width> ppt <height> ppt” for tiling windows
  * rename “new_window” and “new_float” to “default_border” and
    “default_floating_border” (the old names keep working)
  * output names (e.g. “DP2”) can now be used as synonyms for
    monitor names (e.g. “Dell UP2414Q”).
  * the “swap” command now works with fullscreen windows
  * raise floating windows to top when they are focused
    programmatically
  * _NET_ACTIVE_WINDOW: invalidate focus to force SetInputFocus call
  * make focus handling consistent when changing focus between outputs
  * round non-integer Xft.dpi values
  * tiling resize: remove minimum size
  * doc updates to ipc and userguide, some changes to default config
  * i3bar: fix various memory leaks
  * i3bar: fix crash when no status_command is provided
  * fix incorrectly set up signal handling
  * fix crash when specifying invalid con_id for “swap”
  * fix crash upon restart with window marks
  * fix crash when config file does not end in a newline
  * fix crash in append_layout
  * fix crash in layout toggle command
  * fix crash when switching monitors
  * fix use-after-free in randr_init error path
  * fix move accidentally moving windows across outputs
  * fix crash when floating window is tiled while being resized
  * fix out-of-bounds memory read
  * fix memory leak when config conversion fails
  * fix layout toggle split, which didn’t work until enabling
    tabbed/stack mode once
  * move XCB event handling into xcb_prepare_cb
  * avert endless loop on unexpected EOF in ipc messages
  * perform proper cleanup for signals with Term action
  * don’t match containers in the scratchpad with criteria
  * fix “workspace show” related issues
  * fix config file conversion with long variable names
  * fix config file conversion memory initialization
  * prevent access of freed workspace in _workspace_show
  * disable fullscreen when required when programmatically
    focusing windows
  * free last_motion_notify
  * don’t raise floating windows when focused because of
    focus_follows_mouse
  * correctly set EWMH atoms when closing a workspace
  * don’t raise floating windows when workspace is shown
  * keep focus order when encapsulating workspaces
  * validate layout files before loading
- cleanup with spec-cleaner
* Fri Oct 27 2017 dimstar@opensuse.org
- Have i3-gaps-devel conflict with i3-devel.
* Sat Oct  7 2017 aavindraa@gmail.com
- Fix Leap 42.x build
- Drop _service file
- Drop dead code in .spec file
- Properly set "Conflict" to other providers of i3
* Mon Sep 25 2017 aavindraa@gmail.com
- bump to 4.14.1
- Create _service file
- Fix 32-bit ARM build
* Mon Sep  4 2017 aavindraa@gmail.com
- Bump to 4.14
- Reformat spec file to match i3
